@@ -349,17 +349,20 @@ class ImageCLI(DockerCLICaller):
 
         return [Image(self.client_config, x, is_immutable_id=True) for x in ids]
 
-    def prune(self, all: bool = False, filter: Dict[str, str] = {}) -> None:
+    def prune(self, all: bool = False, filter: Dict[str, str] = {}) -> str:
         """Remove unused images
 
         # Arguments
             all: Remove all unused images, not just dangling ones
             filter: Provide filter values (e.g. `{"until": "<timestamp>"}`)
+
+        # Returns:
+            The output of the CLI (the layers removed).
         """
         full_cmd = self.docker_cmd + ["image", "prune", "--force"]
         full_cmd.add_flag("--all", all)
         full_cmd.add_args_list("--filter", format_dict_for_cli(filter))
-        run(full_cmd)
+        return run(full_cmd)
 
     def pull(
         self, x: Union[str, List[str]], quiet: bool = False
